@@ -1,6 +1,6 @@
 /*
  * pcboard.c
- * libansilove 1.1.2
+ * libansilove 1.1.5
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -44,7 +44,7 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	}
 
 	struct fontStruct fontData;
-	uint32_t loop, structIndex;
+	size_t loop = 0, structIndex = 0;
 
 	/* font selection */
 	alSelectFont(&fontData, options->font);
@@ -52,7 +52,7 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	/* libgd image pointers */
 	gdImagePtr canvas;
 
-	uint8_t character, current_character, next_character;
+	uint8_t character, *cursor;
 	uint32_t background = 0, foreground = 7;
 	uint32_t column = 0, row = 0, columnMax = 0, rowMax = 0;
 
@@ -62,20 +62,15 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	/* PCB buffer dynamic memory allocation */
 	pcboard_buffer = malloc(sizeof (struct pcbChar));
 
-	/* reset loop */
-	loop = 0;
-	structIndex = 0;
-
 	while (loop < ctx->length) {
-		current_character = ctx->buffer[loop];
-		next_character = ctx->buffer[loop+1];
+		cursor = &ctx->buffer[loop];
 
 		if (column == 80) {
 			row++;
 			column = 0;
 		}
 
-		switch (current_character) {
+		switch (*cursor) {
 		case LF:
 			row++;
 			column = 0;
@@ -90,14 +85,14 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 			break;
 		case '@':
 			/* PCB sequence */
-			if (next_character == 'X') {
+			if (*++cursor == 'X') {
 				/* set graphics rendition */
 				background = ctx->buffer[loop+2];
 				foreground = ctx->buffer[loop+3];
 				loop += 3;
 			}
 
-			if (next_character == 67 && ctx->buffer[loop+2] == 'L'
+			if (*cursor == 'C' && ctx->buffer[loop+2] == 'L'
 			    && ctx->buffer[loop+3] == 'S') {
 				/* erase display */
 				column = 0;
@@ -109,16 +104,14 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 				loop += 4;
 			}
 
-			if (next_character == 80 && ctx->buffer[loop+2] == 'O'
+			if (*cursor == 'P' && ctx->buffer[loop+2] == 'O'
 			    && ctx->buffer[loop+3] == 'S' && ctx->buffer[loop+4] == ':') {
 				/* cursor position */
 				if (ctx->buffer[loop+6] == '@')
 				{
 					column = ((ctx->buffer[loop+5])-48)-1;
 					loop += 5;
-				}
-				else
-				{
+				} else {
 					column = (10 * ((ctx->buffer[loop+5])-48) + (ctx->buffer[loop+6])-48)-1;
 					loop += 6;
 				}
@@ -147,7 +140,7 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 			pcboard_buffer[structIndex].row = row;
 			pcboard_buffer[structIndex].background = pcb_colors[background];
 			pcboard_buffer[structIndex].foreground = pcb_colors[foreground];
-			pcboard_buffer[structIndex].character = current_character;
+			pcboard_buffer[structIndex].character = *cursor;
 
 			column++;
 			structIndex++;
@@ -167,10 +160,6 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 		return -1;
 	}
 
-	/* allocate black color and create background canvas */
-	gdImageColorAllocate(canvas, 0, 0, 0);
-	gdImageFill(canvas, 0, 0, 0);
-
 	/* allocate color palette */
 	uint32_t colors[16];
 
@@ -180,10 +169,8 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 		    ansi_palette[i*3+2]);
 	}
 
-	uint32_t pcbBufferItems = structIndex;
-
 	/* render PCB */
-	for (loop = 0; loop < pcbBufferItems; loop++) {
+	for (loop = 0; loop < structIndex; loop++) {
 		/* grab our chars out of the structure */
 		column = pcboard_buffer[loop].column;
 		row = pcboard_buffer[loop].row;
