@@ -1,6 +1,6 @@
 /*
  * output.c
- * libansilove 1.1.2
+ * libansilove 1.1.5
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -23,7 +23,11 @@ output(struct ansilove_ctx *ctx, struct ansilove_options *options,
 	/* XXX Allow combining DOS aspect ratio and Retina */
 
 	if (!options->scale_factor && !options->dos) {
+		if (options->mode == ANSILOVE_MODE_TRANSPARENT)
+			gdImageColorTransparent(im_Source, 0);
+
 		ctx->png.buffer = gdImagePngPtr(im_Source, &ctx->png.length);
+
 		gdImageDestroy(im_Source);
 	} else if (options->dos) {
 		gdImagePtr im_DOS;
@@ -39,9 +43,9 @@ output(struct ansilove_ctx *ctx, struct ansilove_options *options,
 		gdImageCopyResampled(im_DOS, im_Source, 0, 0, 0, 0,
 		    im_DOS->sx, im_DOS->sy, im_Source->sx, im_Source->sy);
 
-		gdImageDestroy(im_Source);
-
 		ctx->png.buffer = gdImagePngPtr(im_DOS, &ctx->png.length);
+
+		gdImageDestroy(im_Source);
 		gdImageDestroy(im_DOS);
 	} else {
 		gdImagePtr im_Retina;
@@ -58,8 +62,12 @@ output(struct ansilove_ctx *ctx, struct ansilove_options *options,
 		    im_Retina->sx, im_Retina->sy, im_Source->sx, im_Source->sy);
 
 		/* create retina output image */
-		gdImageDestroy(im_Source);
+		if (options->mode == ANSILOVE_MODE_TRANSPARENT)
+			gdImageColorTransparent(im_Retina, 0);
+
 		ctx->png.buffer = gdImagePngPtr(im_Retina, &ctx->png.length);
+
+		gdImageDestroy(im_Source);
 		gdImageDestroy(im_Retina);
 	}
 
